@@ -1,22 +1,8 @@
 /*
-Copyright (C) 2001 - 2013 Evan Teran
-                          evan.teran@gmail.com
+    SPDX-FileCopyrightText: 2001-2013 Evan Teran <evan.teran@gmail.com>
+    SPDX-FileCopyrightText: 2003-2005 Klaus Niederkrueger <kniederk@math.uni-koeln.de>
 
-Copyright (C) 2003 - 2005 Klaus Niederkrueger
-                          kniederk@math.uni-koeln.de
-
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kcalc_const_menu.h"
@@ -63,7 +49,7 @@ ConstantCategory stringToCategory(const QString &s)
 void KCalcConstMenu::init_consts()
 {
     QDomDocument doc(QStringLiteral("list_of_constants"));
-    QFile file(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("scienceconstants.xml")));
+    QFile file(QStringLiteral(":/kcalc/scienceconstants.xml"));
 
     if (!file.open(QIODevice::ReadOnly)) {
         qDebug() << "Did not find file \"scienceconstants.xml\". No constants will be available.";
